@@ -1,5 +1,7 @@
 import re
 from django.utils.datastructures import SortedDict as OrderedDict
+from django.core.exceptions import ValidationError
+
 try:
     from django.utils import six
 except ImportError:
@@ -28,7 +30,7 @@ class ChoiceItem(object):
     in a python identifier name (ie: "DVD/Movie"). 
     """
     order = 0
-    def __init__(self, value, label=None, order=None):
+    def __init__(self, value=None, label=None, order=None):
         self.value = value
         if order:
             self.order = order
@@ -78,10 +80,10 @@ class DjangoChoicesMeta(type):
                     label = val.label
                 else:
                     label = cls.name_clean.sub(" ", field_name)
-                choices.append((val.value, label))
-                attrs[field_name] = StaticProp(val.value)
+                choices.append((val.value or label, label))
+                attrs[field_name] = StaticProp(val.value or label)
                 setattr(labels, field_name, label)
-                values[val.value] = label 
+                values[val.value or label] = label
             else:
                 choices.append((field_name, val.choices))
 
@@ -97,3 +99,10 @@ class DjangoChoices(six.with_metaclass(DjangoChoicesMeta)):
     choices = ()
     labels = Labels()
     values = {}
+
+    @classmethod
+    def validator(cls, value):
+        if value not in cls.values:
+            raise ValidationError('Select a valid choice. %(value)s is not '
+                                  'one of the available choices.')
+
